package com.junmp.print;

import android.app.Application;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.database.sqlite.SQLiteDatabase;
import android.net.Uri;
import android.os.Environment;
import android.os.Handler;
import android.support.v7.widget.ActionBarContainer;
import android.util.Log;
import android.widget.Toast;

import com.facebook.stetho.Stetho;
import com.junmp.print.app.AppManager;
import com.junmp.print.dao.db.DaoMaster;
import com.junmp.print.dao.db.DaoSession;
import com.junmp.print.dao.entity.JpTabConfig;
import com.junmp.print.util.RmoveFileUtil;

import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;

/**
 * <pre>
 * 描述：
 * 版本：1.0
 * 日期：2018/4/18
 * 作者：ningzp@junmp.com.cn
 * </pre>
 */

public class PrintApplication extends Application {

    /**
     * 上下文对象
     */
    private static Context mContext;

    /**
     * 主线程
     */
    private static Thread mMainThread;

    /**
     * 主线程ID
     */
    private static long mMainThreadId;

    /**
     * 主线程Handler
     */
    private static Handler mHandler;

    private DaoMaster.DevOpenHelper mHelper;
    //private HMROpenHelper mHelper;
    private SQLiteDatabase db;
    private DaoMaster mDaoMaster;
    private static DaoSession mDaoSession;
    //静态单例
    public static PrintApplication instances;
    @Override
    public void onCreate() {
        super.onCreate();
        instances = this;
        mContext = getApplicationContext();
        mMainThread = Thread.currentThread();
        mMainThreadId = android.os.Process.myTid();
        mHandler = new Handler();
        setDatabase();
        creatFile();

        /*IntentFilter filter = new IntentFilter();
        filter.addAction(Intent.ACTION_PACKAGE_ADDED);
        filter.addAction(Intent.ACTION_PACKAGE_REPLACED);
        filter.addAction(Intent.ACTION_PACKAGE_REMOVED);
        filter.addDataScheme("package");
        registerReceiver(InitApkBroadCastReceiver,filter);*/
    }

    private BroadcastReceiver InitApkBroadCastReceiver = new  BroadcastReceiver() {
        @Override
        public void onReceive(Context context, Intent intent) {

            if (Intent.ACTION_PACKAGE_ADDED.equals(intent.getAction())) {
                RmoveFileUtil.rmoveFile(Environment.getExternalStorageDirectory() + "/Download/JPQYHand.apk");
                Toast.makeText(context , "监听到系统广播添加" , Toast.LENGTH_LONG).show();
                Log.d("InitApkBroad","监听到系统广播添加");
            }

            if (Intent.ACTION_PACKAGE_REMOVED.equals(intent.getAction())) {
                RmoveFileUtil.rmoveFile(Environment.getExternalStorageDirectory() + "/Download/JPQYHand.apk");
                Toast.makeText(context , "监听到系统广播移除" , Toast.LENGTH_LONG).show();
                Log.d("InitApkBroad","监听到系统广播移除");
            }

            if (Intent.ACTION_PACKAGE_REPLACED.equals(intent.getAction())) {
                RmoveFileUtil.rmoveFile(Environment.getExternalStorageDirectory() + "/Download/JPQYHand.apk");
                Toast.makeText(context , "监听到系统广播替换" , Toast.LENGTH_LONG).show();
                Log.d("InitApkBroad","监听到系统广播替换");
            }
        }
    };
    public static PrintApplication getInstances(){
        return instances;
    }

    /**
     * 初始化greenDao
     */
    private void setDatabase() {
        // 通过 DaoMaster 的内部类 DevOpenHelper，可以得到一个便利的 SQLiteOpenHelper 对象。
        // 注意：默认的 DaoMaster.DevOpenHelper 会在数据库升级时，删除所有的表，意味着这将导致数据的丢失。
        // 所以，在正式的项目中，还应该做一层封装，来实现数据库的安全升级。
        //mHelper = new HMROpenHelper(this, "storeApp.db", null);
        mHelper = new DaoMaster.DevOpenHelper(this, "storeApp.db", null);
        db = mHelper.getWritableDatabase();
        // 注意：该数据库连接属于 DaoMaster，所以多个 Session 指的是相同的数据库连接。
        mDaoMaster = new DaoMaster(db);
        mDaoSession = mDaoMaster.newSession();
        //PrintApplication.getDaoSession().getJpTabConfigDao().deleteAll();
        JpTabConfig JpTabConfig = new  JpTabConfig(null,2,"csdm","产商代码","1", "1", 30, "", "N",
                "", "N", "");

        PrintApplication.getDaoSession().getJpTabConfigDao().insert(JpTabConfig);
    }

    /**
     * 初始化文件夹
     */
    private void creatFile() {

        //先通过Environment（环境）的getExternalStorageState()方法来获取手机环境下的外置存储卡的状态，判断是否为挂载状态。
        if (Environment.getExternalStorageState().equals(Environment.MEDIA_MOUNTED)) {
            try{
                String fileName = Environment.getExternalStorageDirectory()+"/JPQYHand/";
                mkdir(fileName,"","");
                mkdir(fileName+"ErrorXml/","重复数据","readMe.xml");
                mkdir(fileName+"FwqdjyXml/","校验数据","readMe.xml");
                mkdir(fileName+"TagsXml/","标签","readMe.xml");
                mkdir(fileName+"Update/","发物清单和物资代码","readMe.xml");
            }catch (Exception e){
                e.printStackTrace();

            }

        }

    }

    private void mkdir(String fileName,String note,String file){
        File path = new File(fileName);
        //通知系统刷新文件夹
        Intent intent = new Intent(Intent.ACTION_MEDIA_SCANNER_SCAN_FILE);
        if(!path.exists()){
            path.mkdir();
            try {
                if(!note.equals("")){
                    File pathRead = new File(fileName+file);
                    //新建一个FileOutputStream()，把文件的路径传进去
                    FileOutputStream fileOutputStream = new FileOutputStream(pathRead);
                    //给定一个字符串，将其转换成字节数组
                    byte[] bytes = note.getBytes();
                    //通过输出流对象写入字节数组
                    fileOutputStream.write(bytes);
                    //关流
                    fileOutputStream.close();
                    pathRead.createNewFile();
                }

                //通过文件的对象file的createNewFile()方法来创建文件
                intent.setData(Uri.fromFile(new File(fileName+file)));
                this.sendBroadcast(intent);
            } catch (IOException e) {
                e.printStackTrace();
            }
        }
    }



    /**
    * 获取DaoSession
    */
    public static  DaoSession getDaoSession() {
        return mDaoSession;
    }
    public SQLiteDatabase getDb() {
        return db;
    }

    public static void exit() {
        getApplicationManager().appExit(mContext);
    }

    public static PrintApplication getInstance() {
        return instances;
    }

    private void init() {
        //初始化LEAK内存泄露检查工具
        //LeakCanary.install(this);
        //初始化Stetho调试工具
        Stetho.initialize(
                Stetho.newInitializerBuilder(this)
                        .enableDumpapp(Stetho.defaultDumperPluginsProvider(this))
                        .enableWebKitInspector(Stetho.defaultInspectorModulesProvider(this))
                        .build());

    }

    public static AppManager getApplicationManager() {
        return AppManager.getAppManager();
    }

    public static Context getContext() {
        return mContext;
    }

    public static void setContext(Context mContext) {
        PrintApplication.mContext = mContext;
    }

    public static Thread getMainThread() {
        return mMainThread;
    }

    public static void setMainThread(Thread mMainThread) {
        PrintApplication.mMainThread = mMainThread;
    }

    public static long getMainThreadId() {
        return mMainThreadId;
    }

    public static void setMainThreadId(long mMainThreadId) {
        PrintApplication.mMainThreadId = mMainThreadId;
    }


    public static Handler getMainHandler() {
        return mHandler;
    }

    public static void setMainHandler(Handler mHandler) {
        PrintApplication.mHandler = mHandler;
    }

}
