package com.junmp.print.dao.entity;


import com.facebook.stetho.common.StringUtil;

/**
 * <pre>
 *
 * 描述：解析一些数据
 * 版本：1.0
 * 日期：2017年3月16日 上午10:29:29
 * 作者：ningzp@junmp.com.cn
 *
 * </pre>
 */
public class ParserEpcUtils {

	// 标头信息
	static String CONSTHEADERINFO = "05";
	static String CONSTHEADERINFOBIN = "00000101";
	// 版本号
	static String CONSTVERSION = "11";
	static String CONSTVERSIONBIN = "00010001";
	// 定义静态发行机构标志
	static String CONSTMILITARYPUBLISHFLAG = "000001";
	static String CONSTNATIONPUBLISHFLAG = "000010";
	static String CONSTNATOPUBLISHFLAG = "000011";

	// 无源标签6位字段对应表
	String[] KeyWords = { "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "A", "B", "C", "D", "E", "F", "G", "H", "I",
			"J", "K", "L", "M", "N", "O", "P", "Q", "R", "S", "T", "U", "V", "W", "X", "Y", "Z" };
	String strKeyWords = "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ";

	// 1、标头信息 8位
	String strHexHeaderInfo = ParserEpcUtils.CONSTHEADERINFO;
	String strBinHeaderInfo = ParserEpcUtils.CONSTHEADERINFOBIN; // 2进制

	// 3、组织机构代码 54 每6位代表一个数字或字母，位数不够时用每一个字母使用"0"填充
	String strOrgCode = ""; // 正常组织机构代码
	String strBinOrgCode = "";

	// 4、位品种代码指示长度 4 指示物资代码长度 N*6 = 物资代码长度，默认为6
	String strHexProductCodeLength = "6"; // 16进制
	String strBinProductcodeLength = "0110";// 2进制

	// 5、物资代码
	String strHexProductCode = "000000000"; // 16进制
	String strBinProductCode = "000000000000000000000000000000000000"; // 2进制

	// 6、序列号长充 4位 N*6,现固定为A
	String strHexSerialLength = "A";
	String strBinSerialLength = "1010";

	// 7、版本号 8位 当前版本为"11"
	String strHexVersion = ParserEpcUtils.CONSTVERSION;
	String strBinVersion = ParserEpcUtils.CONSTVERSIONBIN;

	// 8、标签类型 4位 1 - 箱标签
	private String strHexTagType = "1";
	private String strBinTagType = "0001";

	// 9、包装类型 4位 （1-外包装，2-中包装，3-内包装，F-零头配箱）
	private String strHexPacktype = "1";
	private String strBinPacktype = "0001";

	// 11、产品总数量 12位 最大4095
	private String strHexProductNum = "000";
	private String strBinProductNum = "000000000000";

	// 13、产品箱序列号 12位
	private String strHexPackSerialNo = "000";
	private String strBinPackSerialNo = "000000000000";

	// 生产日期 24位
	private String strHexScrq = "120101";
	private String strBinScrq = "000100100000000100000001";

	private String strHexGroupNo = "0";
	private String strBinGroupNo = "0000";

	/***
	 * 1、取得16进制标头信息
	 * 
	 * @return
	 */
	public String getStrHexHeaderInfo() {
		return strHexHeaderInfo;
	}

	/***
	 * 1、取得2进制标头信息
	 * 
	 * @return
	 */
	public String getStrBinHeaderInfo() {
		return strBinHeaderInfo;
	}

	public String getStrOrgCode() {
		return strOrgCode;
	}

	/***
	 * 3、设置组织机构代码 位数：54位 说明：每6位代表一个数字或字母，位数不够时前面用0填充
	 * 
	 * @param strOrgCode
	 */
	public void setStrOrgCode(String strOrgCode) {
		this.strOrgCode = strOrgCode;
	}

	/***
	 * 3、取得2进制组织机构代码 位数：54位 说明：每6位代表一个数字或字母，位数不够时前面用0填充
	 * 
	 * @return
	 */
	public String getStrBinOrgCode() {
		return strBinOrgCode;
	}

	/***
	 * 3、设置2进制组织机构代码
	 * 
	 * @param strBinOrgCode
	 */
	public void setStrBinOrgCode(String strBinOrgCode) {
		this.strBinOrgCode = strBinOrgCode;
	}

	/***
	 * 4、取得16进制品种代码指示长度 位数：4位 说明：指示物资代码长度，N * 6 = 物资代码长度位数 默认值：6
	 * 
	 * @return
	 */
	public String getStrHexProductCodeLength() {
		return strHexProductCodeLength;
	}

	/***
	 * 4、设置16进制品种代码指示长度 位数：4位 说明：指示物资代码长度，N * 6 = 物资代码长度位数 默认值：6
	 * 
	 * @param strHexProductCodeLength
	 */
	public void setStrHexProductCodeLength(String strHexProductCodeLength) {
		this.strHexProductCodeLength = strHexProductCodeLength;
	}

	/***
	 * 4、取得2进制品种代码指示长度 位数：4位 说明：指示物资代码长度，N * 6 = 物资代码长度位数 默认值：6
	 * 
	 * @return
	 */
	public String getStrBinProductcodeLength() {
		return strBinProductcodeLength;
	}

	/***
	 * 4、设置2进制品种代码指示长度 位数：4位 说明：指示物资代码长度，N * 6 = 物资代码长度位数 默认值：6
	 * 
	 * @return
	 */
	public void setStrBinProductcodeLength(String strBinProductcodeLength) {
		this.strBinProductcodeLength = strBinProductcodeLength;
	}

	/***
	 * 5、取得16进制物资代码
	 * 
	 * @return
	 */
	public String getStrHexProductCode() {
		return strHexProductCode;
	}

	/***
	 * 5、设置16进制物资代码
	 * 
	 * @return
	 */
	public void setStrHexProductCode(String strHexProductCode) {
		this.strHexProductCode = strHexProductCode;
	}

	/***
	 * 5、取得2进制物资代码
	 * 
	 * @return
	 */
	public String getStrBinProductCode() {
		return strBinProductCode;
	}

	/***
	 * 5、设置2进制物资代码
	 * 
	 * @return
	 */
	public void setStrBinProductCode(String strBinProductCode) {
		this.strBinProductCode = strBinProductCode;
	}

	/***
	 * 6、取得16进制序列号长度 位数：4 说明：N * 6 默认：A（十进制为10）
	 * 
	 * @return
	 */
	public String getStrHexSerialLength() {
		return strHexSerialLength;
	}

	/***
	 * 6、设置16进制序列号长度 位数：4 说明：N * 6 默认：A（十进制为10）
	 * 
	 * @return
	 */
	public void setStrHexSerialLength(String strHexSerialLength) {
		this.strHexSerialLength = strHexSerialLength;
	}

	/***
	 * 6、设置2进制序列号长度 位数：4 说明：N * 6 默认：A（十进制为10）
	 * 
	 * @return
	 */
	public String getStrBinSerialLength() {
		return strBinSerialLength;
	}

	/***
	 * 6、取得2进制序列号长度 位数：4 说明：N * 6 默认：A（十进制为10）
	 * 
	 * @return
	 */
	public void setStrBinSerialLength(String strBinSerialLength) {
		this.strBinSerialLength = strBinSerialLength;
	}

	/***
	 * 7、取得16进制版本号 位数：8 说明：版本号 默认：当前版本号为11
	 * 
	 * @return
	 */
	public String getStrHexVersion() {
		return strHexVersion;
	}

	/***
	 * 7、设置16进制版本号
	 * 
	 * @return
	 */
	public void setStrHexVersion(String strHexVersion) {
		this.strHexVersion = strHexVersion;
	}

	/***
	 * 7、取得2进制版本号
	 * 
	 * @return
	 */
	public String getStrBinVersion() {
		return strBinVersion;
	}

	/***
	 * 7、设置2进制版本号
	 * 
	 * @return
	 */
	public void setStrBinVersion(String strBinVersion) {
		this.strBinVersion = strBinVersion;
	}

	/***
	 * 8、取得16进制标签类型 位数：4位 默认：1 箱标签
	 * 
	 * @return
	 */
	public String getStrHexTagType() {
		return strHexTagType;
	}

	/***
	 * 8、设置16进制标签类型 位数：4位 默认：1 箱标签
	 * 
	 * @return
	 */
	public void setStrHexTagType(String strHexTagType) {
		this.strHexTagType = strHexTagType;
	}

	/***
	 * 8、取得2进制标签类型 位数：4位 默认：1 箱标签
	 * 
	 * @return
	 */
	public String getStrBinTagType() {
		return strBinTagType;
	}

	/***
	 * 8、设置2进制标签类型 位数：4位 默认：1 箱标签
	 * 
	 * @return
	 */
	public void setStrBinTagType(String strBinTagType) {
		this.strBinTagType = strBinTagType;
	}

	/***
	 * 9、取得16进制包装类型 位数：4位 默认：1为外包装， F为零头配箱
	 * 
	 * @return
	 */
	public String getStrHexPacktype() {
		return strHexPacktype;
	}

	/***
	 * 9、设置16进制包装类型 位数：4位 默认：1为外包装， F为零头配箱
	 * 
	 * @return
	 */
	public void setStrHexPacktype(String strHexPacktype) {
		this.strHexPacktype = strHexPacktype;
	}

	/***
	 * 9、取得2进制包装类型 位数：4位 默认：1为外包装， F为零头配箱
	 * 
	 * @return
	 */
	public String getStrBinPacktype() {
		return strBinPacktype;
	}

	/***
	 * 9、设置2进制包装类型 位数：4位 默认：1为外包装， F为零头配箱
	 * 
	 * @param strBinPacktype
	 */
	public void setStrBinPacktype(String strBinPacktype) {
		this.strBinPacktype = strBinPacktype;
	}

	/***
	 * 11、取得十六进制产品总数量 位数：12位 最大：4096
	 * 
	 * @return
	 */
	public String getStrHexProductNum() {
		return strHexProductNum;
	}

	/***
	 * 11、设置十六进制产品总数量 位数：12位 最大：4096
	 * 
	 * @param strHexProductNum
	 */
	public void setStrHexProductNum(String strHexProductNum) {
		this.strHexProductNum = strHexProductNum;
	}

	/***
	 * 11、取得2进制产品总数量 位数：12位 最大：4096
	 * 
	 * @return
	 */
	public String getStrBinProductNum() {
		return strBinProductNum;
	}

	/***
	 * 11、设置2进制产品总数量 位数：12位 最大：4096
	 * 
	 * @param strBinProductNum
	 */
	public void setStrBinProductNum(String strBinProductNum) {
		this.strBinProductNum = strBinProductNum;
	}

	/***
	 * 取得16进制产品箱序列号 位数：12 说明：顺序码，最大4095
	 * 
	 * @return
	 */
	public String getStrHexPackSerialNo() {
		return strHexPackSerialNo;
	}

	/***
	 * 设置16进制产品箱序列号 位数：12 说明：顺序码，最大4095
	 * 
	 * @param strHexPackSerialNo
	 */
	public void setStrHexPackSerialNo(String strHexPackSerialNo) {
		this.strHexPackSerialNo = strHexPackSerialNo;
	}

	/***
	 * 取得2进制产品箱序列号 位数：12 说明：顺序码，最大4095
	 * 
	 * @return
	 */
	public String getStrBinPackSerialNo() {
		return strBinPackSerialNo;
	}

	/***
	 * 设置2进制产品箱序列号 位数：12 说明：顺序码，最大4095
	 * 
	 * @param strBinPackSerialNo
	 */
	public void setStrBinPackSerialNo(String strBinPackSerialNo) {
		this.strBinPackSerialNo = strBinPackSerialNo;
	}

	public String getStrHexGroupNo() {
		return strHexGroupNo;
	}

	public void setStrHexGroupNo(String strHexGroupNo) {
		this.strHexGroupNo = strHexGroupNo;
	}

	/**
	 * 0000标识一张标签 1000-1#1001-2#1010-3#1011-4
	 */
	public String getStrBinGroupNo() {
		return strBinGroupNo;
	}

	public void setStrBinGroupNo(String strBinGroupNo) {
		this.strBinGroupNo = strBinGroupNo;
	}

	/***
	 * 取得生产日期
	 * 
	 * @return
	 */
	public String getStrBinScrq() {
		return strBinScrq;
	}

	/***
	 * 设置生产日期
	 * 
	 * @param strBinScrq
	 */
	public void setStrBinScrq(String strBinScrq) {
		this.strBinScrq = strBinScrq;
	}

	/***
	 * 取得16进制生产日期 位数：24位
	 * 
	 * @return
	 */
	public String getStrHexScrq() {
		return strHexScrq;
	}

	/***
	 * 设置16进制生产日期 位数：24位
	 * 
	 * @param strHexScrq
	 */
	public void setStrHexScrq(String strHexScrq) {
		this.strHexScrq = strHexScrq;
	}

	/***
	 * 16进制转为2进制
	 * 
	 * @param hexString
	 * @return
	 */
	public String HexString2BinString(String hexString) {
		String binString = "";
		if (hexString.length() > 0) {
			for (int i = 1; i < hexString.length() + 1; i++) {
				String tempString = "";
				tempString = "0000" + Integer.toBinaryString(Integer.parseInt(hexString.substring(i - 1, i), 16));
				binString += tempString.substring(tempString.length() - 4);
			}
		}
		return binString;
	}

	/***
	 * 2进制转为16进制
	 * 
	 * @param binString
	 * @return
	 */
	public String BinString2HexString(String binString) {
		String hexString = "";
		int hexLength = (int) Math.ceil((binString.length() * 1.00) / 4);
		binString = "0000" + binString;
		binString = binString.substring(binString.length() - (hexLength * 4));
		if (binString.length() > 0) {
			for (int i = 0; i < hexLength; i++) {
				String tempString = "";
				tempString = binString.substring(i * 4, (i + 1) * 4);
				hexString += KeyWords[Integer.parseInt(tempString, 2)];
			}
		}
		return hexString;
	}

	/***
	 * 取得字符串 说明：每6位代表一个数字或字母，转换为字符串
	 * 
	 * @param str6Bin
	 * @return
	 */
	public String Transform6Bin2Character(String str6Bin) {
		String characterString = "";
		int characterLength = (int) Math.ceil((str6Bin.length() * 1.00) / 6);
		str6Bin = "000000" + str6Bin;
		str6Bin = str6Bin.substring(str6Bin.length() - (characterLength * 6));
		if (str6Bin.length() > 0) {
			for (int i = 0; i < characterLength; i++) {
				String tempString = "";
				tempString = str6Bin.substring(i * 6, (i + 1) * 6);
				characterString += KeyWords[Integer.parseInt(tempString, 2)];
			}
		}
		return characterString;
	}

	public String TransformCharacter26Bin(String strCharacterString) {
		// 转为大写
		strCharacterString = strCharacterString.toUpperCase();

		String str6BinString = "";
		if (strCharacterString.length() > 0) {
			for (int i = 1; i < strCharacterString.length() + 1; i++) {
				String tempString = strCharacterString.substring(i - 1, i);
				// 前面加000000，并在字符串找到字符，转为2进制
				tempString = "000000" + Integer.toBinaryString(strKeyWords.indexOf(tempString));
				tempString = tempString.substring(tempString.length() - 6);
				str6BinString += tempString;
			}
		}
		return str6BinString;
	}

	/***
	 * 根据实际EPC分解物资信息
	 * 
	 * @param strHexEpc
	 */
	public void UnPackEpc(String strHexEpc) {
		// 将Epc转为2进制Epc编码
		String strBinEpc = this.HexString2BinString(strHexEpc);

		// 1、取得标头信息
		this.strBinHeaderInfo = strBinEpc.substring(0, 8);
		this.strHexHeaderInfo = Integer.toHexString(Integer.parseInt(this.strBinHeaderInfo, 2));

		// 标头信息05
		if (this.strBinHeaderInfo.equals(ParserEpcUtils.CONSTHEADERINFOBIN)) {

			// 3、组织机构代码
			this.strBinOrgCode = strBinEpc.substring(14, 68);
			this.strOrgCode = this.Transform6Bin2Character(this.strBinOrgCode);

			// 4、品种代码指示长度
			this.strBinProductcodeLength = strBinEpc.substring(68, 72);
			this.strHexProductCodeLength = this.BinString2HexString(this.strBinProductcodeLength);
			// 转成10进制长度
			int iProductCodeLength = Integer.parseInt(this.strHexProductCodeLength, 16);
			// 下一位截取操作的起始位

			// 5、物资代码
			// 修改，根据品种代码指示长度，确定物资代码长度
			this.strBinProductCode = strBinEpc.substring(72, 72 + iProductCodeLength * 6);
			this.strHexProductCode = this.BinString2HexString(this.strBinProductCode);

			// 6、序列号长度
			int iSubStart = 72 + iProductCodeLength * 6;
			this.strBinSerialLength = strBinEpc.substring(iSubStart, iSubStart + 4);
			this.strHexSerialLength = this.BinString2HexString(this.strBinSerialLength);
			// 转为10进制长度
			int iSerialLength = Integer.parseInt(this.strHexSerialLength, 16);

			// 具体序列号内容
			String strSerial = strBinEpc.substring(iSubStart + 4, iSubStart + 4 + iSerialLength * 6);

			// 7、版本号
			this.strBinVersion = strSerial.substring(0, 8);
			this.strHexVersion = this.BinString2HexString(this.strBinVersion);

			// 根据版本号来判断，进行不同版本的解析
			if (strHexVersion.equals("11")) {
				// 8、标签类型
				this.strBinTagType = strSerial.substring(8, 12);
				this.strHexTagType = this.BinString2HexString(this.strBinTagType);

				// 判断当前标签是不是箱标签
				if (this.strHexTagType.equals("1")) {

					// 9、包装类型
					this.strBinPacktype = strSerial.substring(12, 16);
					this.strHexPacktype = this.BinString2HexString(this.strBinPacktype);

					// 11、产品总数量
					this.strBinProductNum = strSerial.substring(24, 36);
					this.strHexProductNum = this.BinString2HexString(this.strBinProductNum);

					// 13、产品箱序列号
					this.strBinPackSerialNo = strSerial.substring(40, 52);
					this.strHexPackSerialNo = this.BinString2HexString(this.strBinPackSerialNo);

					this.strBinGroupNo = strSerial.substring(52, 56);
					this.strHexGroupNo = this.BinString2HexString(this.strBinGroupNo);

					// 16、生产日期
					this.strBinScrq = strBinEpc.substring(iSubStart + 4 + iSerialLength * 6,
							iSubStart + 4 + iSerialLength * 6 + 6);
					this.strHexScrq = this.BinString2HexString(this.strBinScrq);

				} else // 托盘标签
				{

				}

			}
		}
	}

	/**
	 * 获取EPC共用的部分作为subEpc
	 * 
	 *
	 *            EPC
	 * @return
	 */
	/*public String getSubEpc(String epc) {
		StringBuffer temp = new StringBuffer();
		if (StringUtil.hasText(epc)) {
			temp.append(epc.substring(0, 41)).append(epc.substring(43, 49));

			return temp.toString();
		}
		return "";
	}*/

	public static void main(String[] args) {
		// ParserEpcUtils productEpc196 = new ParserEpcUtils();
		// String epc5 = "0504000D2490C80C56033C5754CA11110012C006B04170407200";
		// productEpc196.UnPackEpc(epc5);

		// System.out.println(productEpc196.getStrHexScrq());
		// System.out.println(epc5.substring(43, 49));

		// String code = productEpc196.getStrOrgCode();
		// System.out.println(code.contains("993835"));

		// System.out.println("企业编码:" + productEpc196.getStrOrgCode());
		// System.out.println("物资编码：" +
		// Integer.valueOf(productEpc196.getStrBinProductCode(), 2).toString());
		// System.out.println("物资数量：" +
		// Integer.valueOf(productEpc196.getStrBinProductNum(), 2).intValue());
		// System.out.println("箱号：" +
		// Integer.valueOf(productEpc196.getStrBinPackSerialNo(), 2).intValue());
		// System.out.println(productEpc196.getStrHexPackSerialNo());
		// System.out.println("箱号16：" +
		// Integer.valueOf(productEpc196.getStrHexPackSerialNo(), 16).intValue());

		// System.out.println(Integer.valueOf("00B", 16));
		// System.out.println("序1号：" + productEpc196.getStrBinGroupNo());
		// System.out.println("序号：" + Integer.valueOf(productEpc196.getStrBinGroupNo(),
		// 2).intValue());
		// System.out.println("包装类型：" + productEpc196.getStrBinPacktype());
		// System.out.println("包装类型2：" + productEpc196.getStrHexPacktype());

		// System.out.println("生产日期：" + productEpc196.getStrBinScrq());
		// System.out.println("生产日期16：" + productEpc196.getStrHexScrq());

	}

}
