package com.junmp.print.ui;

import android.annotation.SuppressLint;
import android.app.Dialog;
import android.content.Context;
import android.content.DialogInterface;
import android.content.Intent;
import android.media.AudioManager;
import android.media.SoundPool;
import android.os.Bundle;
import android.os.Handler;
import android.os.Looper;
import android.os.Message;
import android.os.PowerManager;
import android.support.annotation.Nullable;
import android.support.v4.app.FragmentActivity;
import android.support.v7.app.AlertDialog;
import android.support.v7.app.AppCompatActivity;
import android.text.TextUtils;
import android.util.Log;
import android.util.TypedValue;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseExpandableListAdapter;
import android.widget.ExpandableListView;
import android.widget.ListAdapter;
import android.widget.ListView;
import android.widget.TextView;

import com.junmp.print.PrintApplication;
import com.junmp.print.R;
import com.junmp.print.app.UserCache;
import com.junmp.print.presenter.BaseActivityPresenter;
import com.junmp.print.presenter.BasePresenter;
import com.junmp.print.ui.matcheck.out.outcount.OutCountActivity;
import com.junmp.print.util.UIUtil;
import com.junmp.print.view.CustomDialog;

import butterknife.BindView;
import butterknife.ButterKnife;



/**
 * <pre>
 * 描述：Activity基类
 * 版本：1.0
 * 日期：2017/8/24
 * 作者：ningzp@junmp.com.cn
 * </pre>
 */

public abstract class BaseActivity<V, T extends BasePresenter<V>> extends AppCompatActivity {

    @BindView(R.id.return_info)
    public TextView mReturnInfoTv;

    /**
     * 自定义风格
     */
    private CustomDialog mDialogWaiting;

    /**
     * 定义业务对象
     */
    protected T mPresenter;
    @Override
    protected void onCreate(@Nullable Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        //设置自定义标题栏

        //  添加当前的activity
        PrintApplication.getApplicationManager().addActivity(this);
        init();
        //判断是否使用MVP模式
        mPresenter = createPresenter();
        if (null != mPresenter) {
            mPresenter.attachView((V) this);
        }

        //子类不需设置布局ID
        setContentView(getLayoutContentViewId());
        ButterKnife.bind(this);

        //开启
        //Awl = new AndroidWakeLock((PowerManager) getSystemService(Context.POWER_SERVICE));

        initView();
        initData();
        initListener();
    }


    /***
     * 在setContentView()调用之前调用，可以设置WindowFeature
     */
    public void init() {

    }

    /**
     * 子类重写初始化UI
     */
    public void initView() {
    }

    /**
     * 子类重写初始化子类数据
     */
    public void initData() {
    }

    /**
     * 子类重写实现子类的事件
     */
    public void initListener() {
    }

    /**
     * 用于创建Presenter和判断是否使用MVP模式(由子类实现)
     */
    protected abstract T createPresenter();

    /**
     * 得到当前界面的布局文件id(由子类实现)
     */
    protected abstract int getLayoutContentViewId();


    @Override
    protected void onDestroy() {
        super.onDestroy();
        if (null != mPresenter) {
            mPresenter.detachView();
        }
    }

    /*按返回键或者home键，都会调用onStop，并将app隐藏至后台*/
    @Override
    protected void onStop() {
        super.onStop();
    }

    @Override
    protected void onPause() {
        super.onPause();
    }
    @Override
    protected void onResume() {

        super.onResume();
    }

    /**
     * 通过Intent跳转
     *
     * @param intent
     */
    public void jumpToActivity(Intent intent) {
        startActivity(intent);
    }

    /**
     * 通过Activity跳转
     *
     * @param activity
     */
    public void jumpToActivity(Class activity) {
        Intent intent = new Intent(this, activity);
        startActivity(intent);
    }

    /**
     * 携带参数通过Activity跳转
     *
     * @param activity
     */
    public void jumpToActivityTakeBy(Class activity, Bundle bundle) {
        Intent intent = new Intent(this, activity);
        intent.putExtras(bundle);
        startActivity(intent);
    }

    /**
     * 携带参数通过Activity跳转
     *
     * @param activity
     */
    public void jumpToActivityTakeByAndClearTop(Class activity, Bundle bundle) {
        Intent intent = new Intent(this, activity);
        intent.setFlags(Intent.FLAG_ACTIVITY_CLEAR_TOP);
        intent.putExtras(bundle);
        startActivity(intent);
    }

    public void jumpToActivityAndClearTask(Class activity) {
        Intent intent = new Intent(this, activity);
        intent.setFlags(Intent.FLAG_ACTIVITY_CLEAR_TASK);
        startActivity(intent);
        finish();
    }

    public void jumpToActivityAndClearTop(Class activity) {
        Intent intent = new Intent(this, activity);
        intent.setFlags(Intent.FLAG_ACTIVITY_CLEAR_TOP);
        startActivity(intent);
    }

    /**
     *修改ListView的高度 适应ScrollView
     */
    public void setListViewHeightBasedOnChildren(ListView listView) {
        ListAdapter listAdapter = listView.getAdapter();
        if (listAdapter == null) {
            return;
        }

        int totalHeight = 0;
        for (int i = 0; i < listAdapter.getCount(); i++) {
            View listItem = listAdapter.getView(i, null, listView);
            listItem.measure(0, 0);  // 获取item高度
            totalHeight += listItem.getMeasuredHeight();
        }
        totalHeight = totalHeight + 160;

        ViewGroup.LayoutParams params = listView.getLayoutParams();
        // 最后再加上分割线的高度和padding高度，否则显示不完整。
        params.height = totalHeight + (listView.getDividerHeight() * (listAdapter.getCount() - 1))
                +listView.getPaddingTop()+listView.getPaddingBottom();
        listView.setLayoutParams(params);
    }

    /**
     *修改ExpandableListView的高度 适应ScrollView
     */
    public void setListViewHeight(ExpandableListView listView) {
        BaseExpandableListAdapter listAdapter = (BaseExpandableListAdapter) listView.getExpandableListAdapter();
        if (listAdapter == null) {
            return;
        }
        int x = (int) TypedValue.applyDimension(TypedValue.COMPLEX_UNIT_DIP, 220,getResources().getDisplayMetrics());
        int totalHeight = x;
        for (int i = 0; i < listAdapter.getGroupCount(); i++) {
            totalHeight += x * listAdapter.getChildrenCount(i);
         }

        ViewGroup.LayoutParams params = listView.getLayoutParams();
        // 最后再加上分割线的高度和padding高度，否则显示不完整。
        params.height = totalHeight;
        listView.setLayoutParams(params);
    }
    /**
     * 显示操作反馈信息
     */
    public void showMessage(String info) {
        mReturnInfoTv.setText(info);
    }


    public void showDialog(String title,String message,DialogInterface.OnClickListener positiveButtonClickListener,DialogInterface.OnClickListener NegativeButtonClickListener){
        // 这里的属性可以一直设置，因为每次设置后返回的是一个builder对象
        AlertDialog.Builder builder = new AlertDialog.Builder(this);
        // 设置提示框的标题
        builder.setTitle(title).
                // 设置提示框的图标
                        setIcon(R.mipmap.ic_launcher).
                // 设置要显示的信息
                        setMessage(message).
                // 设置确定按钮
                        setPositiveButton(UIUtil.getString(R.string.dialog_ok), positiveButtonClickListener).

                // 设置取消按钮,null是什么都不做，并关闭对话框
                        setNegativeButton(UIUtil.getString(R.string.dialog_cancel), NegativeButtonClickListener);

        // 生产对话框
        AlertDialog alertDialog = builder.create();
        // 显示对话框
        alertDialog.show();
    }

    /**
     * 显示等待提示框
     */
    public Dialog showWaitingDialog(String tip) {
        hideWaitingDialog();
        View view = View.inflate(this, R.layout.dialog_waiting, null);
        if (!TextUtils.isEmpty(tip))
            ((TextView) view.findViewById(R.id.tvTip)).setText(tip);
        mDialogWaiting = new CustomDialog(this, view, R.style.MyDialog);
        mDialogWaiting.show();
        mDialogWaiting.setCancelable(false);
        return mDialogWaiting;
    }

    /**
     * 隐藏等待提示框
     */
    public void hideWaitingDialog() {
        if (mDialogWaiting != null) {
            mDialogWaiting.dismiss();
            mDialogWaiting = null;
        }
    }

   /* public void release() {
        if (null != UHF1handler) {
            Comm.stopScan();
        }
        if (null != myapp.Mreader) {
            myapp.Mreader.CloseReader();
        }
        if (null != myapp.Rpower) {
            myapp.Rpower.PowerDown();
        }
        if (null != Comm.baseTabFragment.mReader) {
            Comm.baseTabFragment.mReader.free();
        }
    }*/

}
