package com.junmp.print.ui;

import android.content.Intent;
import android.os.Bundle;
import android.support.annotation.Nullable;
import android.support.v4.app.Fragment;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.TextView;
import com.junmp.print.PrintApplication;
import com.junmp.print.R;
import com.junmp.print.presenter.BasePresenter;

import java.text.SimpleDateFormat;
import java.util.Date;

import butterknife.BindView;
import butterknife.ButterKnife;
import butterknife.Unbinder;

/**
 * <pre>
 * 描述：
 * 版本：1.0
 * 日期：2018/5/18
 * 作者：wangq@junmp.com.cn
 * </pre>
 */

public abstract class BaseFragment <V, T extends BasePresenter<V>> extends Fragment {

    @BindView(R.id.return_info)
    public TextView mReturnInfoTv;
    /**
     * 定义业务对象
     */
    protected T mPresenter;

    private Unbinder unbinder;

    protected abstract int setView();

    protected abstract void init(View view);

    protected abstract void intView(View view);

    @Override
    public void onCreate(@Nullable Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        //判断是否使用MVP模式
        mPresenter = createPresenter();
        if (null != mPresenter) {
            mPresenter.attachView((V) this);
        }

    }

    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container,
                             Bundle savedInstanceState) {
        View view = inflater.inflate(setView(), container, false);
        //返回一个Unbinder值（进行解绑），注意这里的this不能使用getActivity()
        unbinder = ButterKnife.bind(this, view);
        intView(view);
        return view;
       // return inflater.inflate(setView(), container, false);
    }


    @Override
    public void onViewCreated(View view, Bundle savedInstanceState) {
        super.onViewCreated(view, savedInstanceState);
        init(view);
    }

    @Override
    public void onDestroy() {
        super.onDestroy();
        if (null != mPresenter) {
            mPresenter.detachView();
        }
        if (this.unbinder != null) {
            this.unbinder.unbind();
        }
    }



    /**
     * 用于创建Presenter和判断是否使用MVP模式(由子类实现)
     */
    protected abstract T createPresenter();

    /**
     * 通过Activity跳转
     *
     * @param activity
     */
    public void jumpToActivity(Class activity) {
        Intent intent = new Intent(getActivity(), activity);
        startActivity(intent);
    }

    /**
     * 携带参数通过Activity跳转
     *
     * @param activity
     */
    public void jumpToActivityTakeByAndClearTop(Class activity, Bundle bundle) {
        Intent intent = new Intent(getActivity(), activity);
        intent.setFlags(Intent.FLAG_ACTIVITY_CLEAR_TOP);
        intent.putExtras(bundle);
        startActivity(intent);
    }


    /**
     * 显示操作反馈信息
     */
    public void showMessage(String info) {
        //logger.info("Entering the simulation mode."+"----"+sdf.format(new Date())+info+"  \r\n");
        mReturnInfoTv.setText(info);
    }
}
